@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,9 +60,9 @@ public class USMVersion {
 	 * 0.9.0: Beta
 	 * 6.13: Current head for OX release 6.14
 	 */
-	public static final String VERSION = "7.6.3-2";
+	public static final String VERSION = "7.8.0-10";
 
-	public static final String BUILD_NUMBER = "781e738d5f61225e3d5285404efd12571b0ad5ba- 6894";
+	public static final String BUILD_NUMBER = "98e5b5a678ca882029c97db9f8256a01867162bb- 6970";
 
 	public static final String VERSION_BUILD = VERSION + "-" + BUILD_NUMBER;
 }
