@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -768,28 +768,63 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // GET /ajax/mailfilter?action=list&flag=vacation&session=4108cc5c4bee4d309e10b013ad280a90 HTTP/1.1\r\n
         // RESULT:
         // {"data":[{"active":true,"id":0,"test":{"id":"true"},"rulename":"Abwesenheit","position":0,"actioncmds":[{"id":"vacation","days":"7","text":"This is a test Out Of Office email.","addresses":["user5@ox-p5.microdoc.com","user5@ox.
-        Vacation vacation = new Vacation();
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(FLAG, Vacation.RULE_ID);
         JSONResult jResult = _ajaxAccess.doGet(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_LIST, session, parameters);
         checkResult(jResult, JSONResultType.JSONObject);
         try {
             JSONArray jsonar = jResult.getJSONObject().getJSONArray(CommonConstants.RESULT_DATA);
-            if(jsonar != null && jsonar.length() > 0)  
-                vacation = new Vacation(jsonar.getJSONObject(0));
-            return vacation.toJSONObject();
+            if(jsonar != null && jsonar.length() > 0)  {
+                Vacation vacation = new Vacation(jsonar.getJSONObject(0));
+                return vacation.toJSONObject();
+            }
         } catch (JSONException e) {
             LOG.error(session + " Can not read the vacation rule", e);
         }
         return null;
     }
+    
+    public boolean hasVacationRuleTimes(Session session) throws USMException {
+        // GET /ajax/mailfilter?action=config
+        // RESULT:
+        
+        // for Mailbackened Postfix
+        // {"data":{"tests":[{"test":"address","comparison":["user","detail"]},{"test":"envelope","comparison":["regex","is","contains","matches"]},
+        // {"test":"exists","comparison":[]},{"test":"false","comparison":[]},{"test":"true","comparison":[]},{"test":"not","comparison":[]},
+        // {"test":"size","comparison":["over","under"]},{"test":"header","comparison":["regex","is","contains","matches"]},{"test":"allof","comparison":[]},
+        // {"test":"anyof","comparison":[]}],
+        // "actioncommands":["keep","discard","redirect","move","reject","stop","vacation","addflags"]}}
+        
+        // for Mailbackened Dovecut
+        // {"data":{"tests":[{"test":"address","comparison":["user","detail"]},{"test":"envelope","comparison":["regex","is","contains","matches"]},
+        // {"test":"exists","comparison":[]},{"test":"false","comparison":[]},{"test":"true","comparison":[]},{"test":"not","comparison":[]},
+        // {"test":"size","comparison":["over","under"]},{"test":"header","comparison":["regex","is","contains","matches"]},{"test":"allof","comparison":[]},
+        // {"test":"anyof","comparison":[]},{"test":"body","comparison":["regex","is","contains","matches"]},
+        // {"test":"currentdate","comparison":["ge","le","is","contains","matches"]}],
+        // "actioncommands":["keep","discard","redirect","move","reject","stop","vacation","notify","addflags","addheader","deleteheader","set"]}}
+        Map<String, String> parameters = new HashMap<String, String>();
+        JSONResult jResult = _ajaxAccess.doGet(MAILFILTER_AJAX_PATH, "config", session, parameters);
+        checkResult(jResult, JSONResultType.JSONObject);
+        try {
+            JSONArray tests = jResult.getJSONObject().getJSONObject("data").getJSONArray("tests");
+            for (int i = 0; tests != null && i < tests.length(); i++) {
+                JSONObject test = tests.getJSONObject(i);
+                if ((test.opt("test")).equals("currentdate"))
+                    return true;
+            }
+        } catch (JSONException e) {
+            LOG.error(session + " Can not read the mailfilter config", e);
+        }
+        return false;
+    }
+
 
     public void setVacationRule(Session session, JSONObject rule) throws USMException {
         // PUT /ajax/mailfilter?action=new&session=ae231c985599470bb7d55bc393ba3779 HTTP/1.1\r\n
         // {"rulename":"Abwesenheit","active":true,"flags":["vacation"],"test":{"id":"true"},"actioncmds":[{"id":"vacation","days":10,"addresses":["user4@ox-p5.microdoc.com"],"text":"This is a test","subject":"Test Out of Office"}]}
         // RESULT : {"data":0}
         Map<String, String> parameters = new HashMap<String, String>();
-        JSONObject requestBody = createVacationRequestBody(rule);
+        JSONObject requestBody = rule;
         JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_NEW, session, parameters, requestBody);
         checkResult(jResult, JSONResultType.JSONObject);
     }
@@ -800,7 +835,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // {"rulename":"Abwesenheit","active":true,"flags":["vacation"],"test":{"id":"true"},"actioncmds":[{"id":"vacation","days":10,"addresses":["user4@ox-p5.microdoc.com","user4@ox.microdoc.de"],"text":"This is a test","subject":"Test
         // RESULT: {"data":null}
         Map<String, String> parameters = new HashMap<String, String>();
-        JSONObject requestBody = createVacationRequestBody(rule);
+        JSONObject requestBody = rule;
         JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_UPDATE, session, parameters, requestBody);
         checkResult(jResult, JSONResultType.JSONObject);
     }
@@ -824,26 +859,6 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         }
     }
 
-    private JSONObject createVacationRequestBody(JSONObject rule) throws OXCommunicationException {
-        Vacation vacation = new Vacation(rule);
-        JSONObject requestBody = new JSONObject();
-        try {
-            requestBody.put("rulename", Vacation.RULENAME);
-            requestBody.put(Vacation.ACTIVE, vacation.isActive());
-            requestBody.put("flags", (new JSONArray()).put(Vacation.RULE_ID));
-            requestBody.put("id", vacation.getId());
-            requestBody.put("test", new JSONObject("{\"id\":\"true\"}"));
-            requestBody.put("actioncmds", (new JSONArray()).put(vacation.toActionCmdObject()));
-        } catch (JSONException e) {
-            throw generateException(
-                USMContentTypesMailErrorCodes.ERROR_ON_VACATION_REQUEST_CREATE_2,
-                null,
-                "Vacation Rule: can not create request Body",
-                e);
-        }
-        return requestBody;
-    }
-
     @Override
     protected void addObjectsLimitParameters(Session session, Map<String, String> parameters) {
         int mailLimit = session.getMailLimit();
