@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -101,6 +101,16 @@ public class MeetingRequestResponseUtil {
 
     public static DataObject getAppointmentObjectFromInvitation(DataObject changeObject, Session session, String attSeqId) throws USMException, JSONException, StorageAccessException, USMStorageException {
         JSONObject iTipAnswer = ((MailContentType) changeObject.getContentType()).analyzeICalAttachment(changeObject, attSeqId);
+        if (iTipAnswer.has("actions")) {
+            JSONArray actions = iTipAnswer.getJSONArray("actions");
+            if (actions.length()>0) {
+                // expecting actions=["ignore"]
+                // no documentation available
+                if ("ignore".equals(actions.get(0).toString()))
+                    return null;
+            }
+        }
+
         JSONObject change = getChangeFromITipAnswer(iTipAnswer);
         ContentType calendarContentType = getCalendarContentType(session);
         if (iTipAnswer.has("messageType") && "cancel".equals(iTipAnswer.getString("messageType"))) {
