@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -91,8 +91,8 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 			new ContentTypeField(104, CommonConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments
 			//Detailed task and appointment data
 			new ContentTypeField(200, CommonCalendarTasksFieldNames.TITLE, STRING), //Short description.
-			new ContentTypeField(201, CommonCalendarTasksFieldNames.START_DATE, TIME), //Inclusive start of the event as Date for tasks and whole day appointments and Time for normal appointments
-			new ContentTypeField(202, CommonCalendarTasksFieldNames.END_DATE, TIME), //Exclusive end of the event as Date for tasks and whole day appointments and as Time for normal appointments
+			new ContentTypeField(201, CommonCalendarTasksFieldNames.START_DATE, TIME), //Inclusive start of the event as Date for tasks and whole day appointments and Time for normal appointments * DEPRECATED since 7.6.1
+			new ContentTypeField(202, CommonCalendarTasksFieldNames.END_DATE, TIME), //Exclusive end of the event as Date for tasks and whole day appointments and as Time for normal appointments  * DEPRECATED SINCE 7.6.1
 			new ContentTypeField(203, CommonCalendarTasksFieldNames.NOTE, STRING), //Long description
 			new ContentTypeField(204, CommonCalendarTasksFieldNames.ALARM, TIME), //Specifies when to notify the participants as the number of minutes before the end of the task or before the start of the appointment
 			new ContentTypeField(207, CommonCalendarTasksFieldNames.RECURRENCE_POSITION, NUMBER), //1-based position of an individual appointment in a sequence. Present if and only if recurrence_type > 0
@@ -124,6 +124,10 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 			new ContentTypeField(102, TaskConstants.COLOR_LABEL, NUMBER), // Number from 1-10
 			new ContentTypeField(105, CommonConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
 			new ContentTypeField(223, CommonCalendarTasksFieldNames.UID, STRING), //the UID of the task
+			
+			new ContentTypeField(316, TaskConstants.START_TIME, TIME), //Inclusive start as Date for whole day tasks and Time for normal tasks. 
+            new ContentTypeField(317, TaskConstants.END_TIME, TIME), //Exclusive end as Date for whole day tasks and as Time for normal tasks. 
+            new ContentTypeField(401, TaskConstants.FULL_TIME, BOOLEAN), //True if the event is a whole day appointment or task, false otherwise. 
 	};
 
 	private TaskContentTypeTransferHandlerImpl _transferHandler;
@@ -208,4 +212,5 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
     public Object getObjectGroupOwner(DataObject object) {
 		return object.getID();
 	}
+	
 }
