@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -424,15 +424,6 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         return isAppointmentException(dataObject);
     }
 
-    protected static boolean isFolder(DataObject dataObject) {
-        if(dataObject == null)
-            return false;
-        ContentType contentType = dataObject.getContentType();
-        if (contentType == null || contentType.getCode() != DefaultContentTypes.FOLDER_CODE)
-            return false;
-        return true;
-    }
-
     protected void addOptionalFolderUUID(DataObject o, JSONObject object) throws USMJSONAPIException, JSONException {
         if (object.has(FOLDER_ID)) {
             initAllFolders();
