@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,6 +58,7 @@ import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.startup.ThreadControlService;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.InvalidUUIDException;
@@ -73,7 +74,7 @@ import com.openexchange.usm.json.USMJSONAPIException;
 import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
-import com.openexchange.usm.json.util.ThreadControl;
+import com.openexchange.usm.json.util.ThreadControlReference;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.util.JSONToolkit;
 import com.openexchange.usm.util.UUIDToolkit;
@@ -106,13 +107,13 @@ public class PingHandler extends NormalCommandHandler {
 
     @Override
     public ResponseObject handleRequest() throws USMJSONAPIException {
-        ThreadControl threadControl = ThreadControl.getInstance();
+        ThreadControlService threadControl = ThreadControlReference.getThreadControlService();
         Thread currentThread = Thread.currentThread();
         JSONArray objectUUIDs = _parameters.has(OBJECTIDS) ? getJSONArray(_parameters, OBJECTIDS) : null;
         boolean threadAdded = false;
         try {
             String[] oxIDs = extractOXIdsFromUUIDArray(objectUUIDs);
-            threadAdded = threadControl.addThread(currentThread);
+            threadAdded = null == threadControl ? false : threadControl.addThread(currentThread);
             ObjectChanges changes = getSession().waitForChanges(_watchFolderHierarchyChanges, oxIDs, 0);
             JSONArray resultArray = null;
             if (changes != null) {
@@ -150,7 +151,7 @@ public class PingHandler extends NormalCommandHandler {
         } catch (JSONException e) {
             throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.PING_JSON_ERROR, e);
         } finally {
-            if (threadAdded) {
+            if (threadAdded && null != threadControl) {
                 threadControl.removeThread(currentThread);
             }
         }
