@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,6 +61,7 @@ import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID
 import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import static com.openexchange.usm.json.response.ResponseStatusCode.*;
 import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -70,11 +71,15 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
+
 import javax.servlet.http.HttpServletRequest;
+
 import org.json.JSONArray;
 import org.json.JSONObject;
+
 import com.openexchange.usm.api.contenttypes.common.ContentType;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.FolderConstants;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.exceptions.InvalidUUIDException;
@@ -180,7 +185,6 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             }
             syncId = finishProcessingAndSaveNewState(_syncResult, _folderToSync, syncId);
             JSONObject response = createResponseFromSyncResults(_syncResult, syncId);
-            _swapUUIDsMap.clear();
             logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
             if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
                 _servlet.getAccessLimiter().badAccessEncountered(_session);
@@ -327,12 +331,8 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				_folderClientChangesArray = filterFoldersWithErrors(createFolderChangesArray(syncId));
 				Arrays.sort(_folderClientChangesArray, new FolderHierarchyComparator(_folderClientChangesArray,
 						_servlet.getJournal()));
-				SyncResult result = _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
+				return _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
                     _folderClientChangesArray);
-
-				JSONArray deleted = new JSONArray();
-				findSwappedStandardFolders(buildClientChangesArray(result.getChanges(), deleted), result.getNewState());
-				return result;
 			}
 			_serverChangesMayBeAvailable = _session.needsSynchronization(_folderToSync.getID());
 			_clientChangesArray = filterDataObjectsWithErrors(buildClientRequestArray(_folderToSync, syncId, conflictResolution));
@@ -380,6 +380,35 @@ public class SyncUpdateHandler extends SyncCommandHandler {
         return notExistingStandardFolders;
     }
 
+    /**
+     * @param folder
+     * @param useOriginalContent for modifications, determine if the current or original content of the object should be used
+     * @return standard_folder_type if required standard folder, otherwise 0
+     */
+    private static int getRequiredStandardFolderType(DataObject folder, boolean useOriginalContent) {
+        Object fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER);
+        if (!(fieldValue instanceof Boolean) || !((Boolean) fieldValue).booleanValue())
+            return 0; // No standard folder -> not required
+        fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER_TYPE) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+        if (fieldValue instanceof Number) {
+            int standardFolderType = ((Number) fieldValue).intValue();
+            switch (standardFolderType) {
+            case 1: // Task
+            case 2: // Calendar
+            case 3: // Contact
+            case 7: // Inbox
+            case 9: // Drafts
+            case 10: // Sent
+            case 11: // Spam
+            case 12: // Trash
+                return standardFolderType;
+            default:
+                break;
+            }
+        }
+        return 0;
+    }
+
     private Folder[] createFolderChangesArray(long syncId) throws StorageAccessException, USMStorageException,
 			USMJSONAPIException, SlowSyncRequiredException {
 		Folder[] originalFolders = _session.getCachedFolders(syncId);
