@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,9 +69,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.6.3-2";
+    public static final String VERSION = "7.8.0-10";
 
-    public static final String BUILD_NUMBER = "781e738d5f61225e3d5285404efd12571b0ad5ba- 6894";
+    public static final String BUILD_NUMBER = "98e5b5a678ca882029c97db9f8256a01867162bb- 6970";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -81,13 +81,11 @@ public final class USMJSONVersion {
 
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.2.0");
     
-    public static final USMJSONVersion SUPPORTS_STANDARD_FOLDER_SWAPPING = new USMJSONVersion("2.3.0");
-    
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754 = new USMJSONVersion("2.1.0");
 
     private static final USMJSONVersion _CURRENT_VERSION = _SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE;
 
-    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_STANDARD_FOLDER_SWAPPING;
+    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_CONTACT_IMAGE_STREAMING;
 
     private static final List<USMJSONVersion> _supportedVersions = new ArrayList<USMJSONVersion>();
 
@@ -95,7 +93,6 @@ public final class USMJSONVersion {
         if (_supportedVersions.isEmpty()) {
             synchronized (_supportedVersions) {
                 if (_supportedVersions.isEmpty()) {
-                    _supportedVersions.add(SUPPORTS_STANDARD_FOLDER_SWAPPING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754);
                     _supportedVersions.add(SUPPORTS_ATTACHMENT_STREAMING);
@@ -152,10 +149,6 @@ public final class USMJSONVersion {
         return !getUsedVersion(session).isOlder(SUPPORTS_CONTACT_IMAGE_STREAMING.getVersion(), 3);
     }
 
-    public static boolean supportsStandardFolderSwapping(Session session) {
-        return !getUsedVersion(session).isOlder(SUPPORTS_STANDARD_FOLDER_SWAPPING.getVersion(), 3);
-    }
-
     public static Version getUsedVersion(Session session) {
         return Version.fromString(session.getPersistentField(_CLIENT_USM_JSON_VERSION_KEY));
     }
