@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2013 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -61,7 +61,7 @@ import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.openexchange.groupware.settings.PreferencesItemService;
 import com.openexchange.groupware.settings.tree.modules.interfaces.USM_JSON;
 import com.openexchange.groupware.settings.tree.modules.interfaces.USM_JSONActive;
-import com.openexchange.startup.SignalStartedService;
+import com.openexchange.startup.ThreadControlService;
 import com.openexchange.usm.api.configuration.ConfigurationManager;
 import com.openexchange.usm.api.configuration.ConfigurationProperties;
 import com.openexchange.usm.api.contenttypes.common.ContentTypeManager;
@@ -82,7 +82,7 @@ public class USMJSONServletActivator extends AbstractUSMActivator {
 
     private volatile String servletAlias;
     private volatile ServiceTracker<ExecutorService, ExecutorService> executorTracker;
-    private volatile ServiceTracker<SignalStartedService, SignalStartedService> startUpTracker;
+    private volatile ServiceTracker<ThreadControlService, ThreadControlService> threadControlTracker;
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -133,7 +133,7 @@ public class USMJSONServletActivator extends AbstractUSMActivator {
             @Override
             public ExecutorService addingService(ServiceReference<ExecutorService> reference) {
                 Object vendor = reference.getProperty(Constants.SERVICE_VENDOR);
-                if (null != vendor && "Open-Xchange Inc.".equals(vendor.toString())) {
+                if (null != vendor && "OX Software GmbH".equals(vendor.toString())) {
                     ExecutorService executor = context.getService(reference);
                     USMJSONServlet.setExecutorService(executor);
                     return executor;
@@ -151,7 +151,7 @@ public class USMJSONServletActivator extends AbstractUSMActivator {
             public void removedService(ServiceReference<ExecutorService> reference, ExecutorService executor) {
                 if (null != executor) {
                     Object vendor = reference.getProperty(Constants.SERVICE_VENDOR);
-                    if (null != vendor && "Open-Xchange Inc.".equals(vendor.toString())) {
+                    if (null != vendor && "OX Software GmbH".equals(vendor.toString())) {
                         USMJSONServlet.setExecutorService(null);
                     }
                     context.ungetService(reference);
@@ -161,9 +161,9 @@ public class USMJSONServletActivator extends AbstractUSMActivator {
         this.executorTracker = executorTracker;
         executorTracker.open();
 
-        ServiceTracker<SignalStartedService, SignalStartedService> startUpTracker = new ServiceTracker<SignalStartedService, SignalStartedService>(context, SignalStartedService.class, new SignalStartedTracker(context));
-        this.startUpTracker = startUpTracker;
-        startUpTracker.open();
+        ServiceTracker<ThreadControlService, ThreadControlService> threadControlTracker = new ServiceTracker<ThreadControlService, ThreadControlService>(context, ThreadControlService.class, new ThreadControlTracker(context));
+        this.threadControlTracker = threadControlTracker;
+        threadControlTracker.open();
     }
 
     @Override
@@ -174,10 +174,10 @@ public class USMJSONServletActivator extends AbstractUSMActivator {
             this.executorTracker = null;
         }
 
-        ServiceTracker<SignalStartedService, SignalStartedService> startUpTracker = this.startUpTracker;
-        if (null != startUpTracker) {
-            startUpTracker.close();
-            this.startUpTracker = null;
+        ServiceTracker<ThreadControlService, ThreadControlService> threadControlTracker = this.threadControlTracker;
+        if (null != threadControlTracker) {
+            this.threadControlTracker = null;
+            threadControlTracker.close();
         }
 
         HttpService httpService = (HttpService) getService(HttpService.class);
