@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -424,6 +424,22 @@ public abstract class AbstractMimeMailBuilder {
         return defaultVal;
     }
 
+    protected String getValue(MimePart part, String key, int i, String defaultVal) {
+        if (part == null)
+            return defaultVal;
+        try {
+            String[] values = part.getHeader(key);
+            if (values == null || values.length == 0)
+                return defaultVal;
+            if (i >= values.length || i<0)
+                return defaultVal;
+            return values[i];
+        }
+        catch (MessagingException e) {
+            return defaultVal;
+        }
+    }
+
     protected String buildContentDispositionAsString(Object header) throws JSONException, USMJSONAPIException {
         ContentDisposition contentDisp = new ContentDisposition();
         try {
