@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -137,7 +137,7 @@ public class MimeMailBuilder extends AbstractMimeMailBuilder {
 					try {
 						//add headers
 						String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, "quoted-printable");
-						appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
+						setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
 						appendHeadersToPart(part, headers, contentTypeOfPart);
 						//build text part
 						String content = (body != null && body.has(CommandConstants.DATA_KEY)) ? body.getString(CommandConstants.DATA_KEY) : "";
@@ -156,7 +156,7 @@ public class MimeMailBuilder extends AbstractMimeMailBuilder {
 					String content = body.getString(CommandConstants.DATA_KEY);
 					String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, null);
 					if (CommandConstants.BASE64.equals(encoding)) {
-						appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
+						setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
 						part.setDataHandler(new DataHandler(new ByteArrayDataSource(Toolkit.decodeBase64(content),
 								mailcontentTypeAttachment)));
 					} else {
