@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -221,12 +221,12 @@ public class StreamingMimeMailBuilder extends AbstractMimeMailBuilder {
                 } else if (contentTypeOfPart.startsWith(CONTENTTYPE_TEXT_PREFIX)) {
                         //add headers
                         String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, "quoted-printable");
-                        appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
+                        setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
                         part.setHeader(CONTENT_TYPE_UPPER, contentTypeOfPart);
                         setBodyOfPart(part, contentTypeOfPart, body, headers);
                 } else {
                     String encoding = getValue(headers, CONTENT_TRANSFER_ENCODING, 0, null);
-                    appendHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
+                    setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, encoding);
                     part.setHeader(CONTENT_TYPE_UPPER, contentTypeOfPart);
                     setBodyOfPart(part, contentTypeOfPart, body, headers);
                 }
