@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,7 +52,6 @@ package com.openexchange.usm.session.dataobject;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -316,22 +315,4 @@ public class DataObjectSet implements Collection<DataObject> {
     public Set<String> getIDs() {
         return _idMap.keySet();
     }
-    
-    public void swapUUIDs(Map<UUID, UUID> swapUUIDsMap) {
-        Set<UUID> processedSwapUuids = new HashSet<UUID>();
-        for (UUID uuid1: swapUUIDsMap.keySet()) {
-            UUID uuid2 = swapUUIDsMap.get(uuid1);
-            if (!uuid1.equals(uuid2) && uuid2 != null && !processedSwapUuids.contains(uuid1) && contains(uuid1) && contains(uuid2)) {
-                DataObject obj1 = remove(uuid1);
-                DataObject obj2 = remove(uuid2);
-                DataObject copy1 = obj1.createCopy(false);
-                DataObject copy2 = obj2.createCopy(false);
-                copy1.setUUID(uuid2);
-                copy2.setUUID(uuid1);
-                add(copy1);
-                add(copy2);
-                processedSwapUuids.add(uuid2);
-            }
-        }
-    }
 }
