@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.CountDownLatch;
 import javax.management.MalformedObjectNameException;
 import javax.management.NotCompliantMBeanException;
 import javax.management.ObjectName;
@@ -120,7 +123,7 @@ public class SessionManagerImpl implements SessionManager {
     // LATER we might want to make this constant configurable
     private final static long ACCESS_CHECK_INTERVAL = 300000L;
 
-    private final static long ONE_HOUR_IN_MILLISECONDS = 24L * 60L * 60L * 1000L;
+    private final static long ONE_HOUR_IN_MILLISECONDS = 60L * 60L * 1000L;
 
     private final static long ONE_DAY_IN_MILLISECONDS = 24L * ONE_HOUR_IN_MILLISECONDS;
 
@@ -204,6 +207,8 @@ public class SessionManagerImpl implements SessionManager {
 
     private ClusterLockService clusterLockService;
 
+    private static final ConcurrentMap<SessionID, AcquiredLatch> SYNCHRONIZER = new ConcurrentHashMap<SessionID, AcquiredLatch>(256);
+
     /**
      * This constructor is used only for tests of the IncrementalContentSyncer and SlowContentSyncer.
      * 
@@ -449,11 +454,29 @@ public class SessionManagerImpl implements SessionManager {
         return sessionDataStorage.sessionExistsForDevice(session);
     }
 
+    private static AcquiredLatch acquireFor(SessionID key) {
+        AcquiredLatch latch = SYNCHRONIZER.get(key);
+        if (null == latch) {
+            AcquiredLatch newLatch = new AcquiredLatch(Thread.currentThread(), new CountDownLatch(1));
+            // it could happen that a concurrent thread is faster
+            latch = SYNCHRONIZER.putIfAbsent(key, newLatch);
+            if (null == latch) {
+                latch = newLatch;
+            }
+        }
+        return latch;
+    }
+
+    private static void releaseFor(SessionID key) {
+        SYNCHRONIZER.remove(key);
+    }
+
     @Override
     public @NonNull Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
         SessionID id = new SessionID(user, protocol, device);
         SessionImpl session = _sessionStorage.getSession(id);
         if (session != null) {
+            boolean removeSession = true;
             try {
                 if (!session.getPassword().equals(password)) {
                     session.setPassword(password);
@@ -463,16 +486,60 @@ public class SessionManagerImpl implements SessionManager {
                 session.updateClientIp(clientIP);
                 if (recheckUSMAccess(initializer, session)) {
                     updateLastUSMAccess(session);
+                    removeSession = false;
                     return session;
                 }
-            } catch (USMException e) {
-                _sessionStorage.removeSession(session);
-                throw e;
+            } finally {
+                if (removeSession) {
+                    _sessionStorage.removeSession(session);
+                }
             }
             // Cached Session is no longer present in DB, start from scratch
             _sessionStorage.removeSession(session);
         }
-        session = new SessionImpl(this, user, password, protocol, device, initializer);
+
+        AcquiredLatch acquiredLatch = acquireFor(id);
+        CountDownLatch latch = acquiredLatch.latch;
+        if (Thread.currentThread() == acquiredLatch.owner) {
+            // Initialize a new session
+            try {
+                Session newSession = initNewSessionFor(user, password, protocol, device, initializer, clientIP, xHeaders);
+                acquiredLatch.result.set(newSession);
+                return newSession;
+            } catch (USMException e) {
+                acquiredLatch.result.set(e);
+                throw e;
+            } catch (Exception e) {
+                USMException usmExc = new USMException(USMSessionManagementErrorCodes.SESSION_INITIALIZATION_FAILED, e);
+                acquiredLatch.result.set(usmExc);
+                throw usmExc;
+            } finally {
+                latch.countDown();
+                releaseFor(id);
+            }
+        }
+        // A concurrent thread is already running
+        try {
+            LOG.debug("I need to wait for a concurrent thread which does the login already for session " + id);
+
+            // Need to await 'til login done by concurrent thread
+            latch.await();
+
+            // Check if already locally available...
+            Object result = acquiredLatch.result.get();
+
+            if (result instanceof USMException) {
+                throw  (USMException) result;
+            }
+            // return the session which was created by the concurrent thread
+            return (Session) result;
+        } catch (InterruptedException e) {
+            throw new USMException(USMSessionManagementErrorCodes.SESSION_INITIALIZATION_FAILED, e);
+        }
+    }
+
+    private @NonNull Session initNewSessionFor(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
+        SessionImpl session = new SessionImpl(this, user, password, protocol, device, initializer);
         session.setClientIp(clientIP);
         session.setXRequestHeaders(xHeaders);
         _oxAjaxAccess.login(session);
@@ -675,7 +742,7 @@ public class SessionManagerImpl implements SessionManager {
         }
     }
 
-    public static DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
+    public DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
         boolean useModifiedUUID = o.getSession().getUserIdentifier() != o.getParentFolderOwnerID();
         if (oldData != null) {
             DataObject oldObject = oldData.get(o.getID());
@@ -690,22 +757,8 @@ public class SessionManagerImpl implements SessionManager {
             if (newestCachedData == null)
                 newestCachedData = new DataObjectSet(o.getSession().getCachedFolders());
             DataObject cachedFolder = newestCachedData.get(o.getID());
-            if (cachedFolder != null) {
-                if (oldData != null) {
-                    DataObject oldFolder = oldData.get(cachedFolder.getUUID());
-                    if (oldFolder != null) {
-                      if (!oldFolder.getID().equals(cachedFolder.getID()) && newestCachedData.get(oldFolder.getID()) != null) {
-                          // we have a swap situation
-                          DataObject swappedFolder = newestCachedData.get(oldFolder.getID());
-                          if (swappedFolder != null && swappedFolder.getUUID() != null) {
-                              o.setUUID(swappedFolder.getUUID());
-                              break;
-                          }
-                      }
-                    }
-                }
+            if (cachedFolder != null)
                 o.setUUID(cachedFolder.getUUID());
-            }
             break;
         case DefaultContentTypes.MAIL_CODE:
             if (newestCachedData == null)
